%global srcname docutils

Name:		python-%{srcname}
Summary:	Python Documentation Utilities
Version:	0.11
Release:	%mkrel 3
URL:		http://docutils.sourceforge.net/
License:	Public Domain and BSD and Python and GPLv3+
Group:		Development/Python
Source:		http://downloads.sourceforge.net/project/docutils/docutils/%{version}/%{srcname}-%{version}.tar.gz
# Sometimes we need snapshots.  Instructions below:
# svn co -r 7502 https://docutils.svn.sourceforge.net/svnroot/docutils/trunk/docutils
# cd docutils
# python setup.py sdist
# The tarball is in dist/docutils-VERSION.tar.gz
#Source:		%{srcname}-%{version}.tar.gz

# Disable some tests known to fail with Python 3.3
# Bug reports filed upstream as:
#   https://sourceforge.net/tracker/?func=detail&aid=3555164&group_id=38414&atid=422030
# and:
#   http://sourceforge.net/tracker/?func=detail&aid=3561133&group_id=38414&atid=422030
# Unicode test is failing because of a python3.3b2 bug:
# ImportError(b'str').__str__() returns bytes rather than str
# http://bugs.python.org/issue15778
Patch100: disable-failing-tests.patch

BuildArch:	noarch
BuildRequires:	pkgconfig(python)
BuildRequires:	emacs
BuildRequires:	python-setuptools
Suggests:	python-imaging

%description
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

%package -n python3-%{srcname}
Summary:	System for processing plaintext documentation for python3
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:  python-tools
Suggests:	python3-imaging

%description -n python3-%{srcname}
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

This package contains the module, ported to run under python3.

%prep
%setup -q -n %{srcname}-%{version}
%patch100 -p1 -b .disable-failing-tests

# Remove shebang from library files
for file in docutils/utils/{code_analyzer.py,punctuation_chars.py,error_reporting.py} docutils/utils/math/{latex2mathml.py,math2html.py} docutils/writers/xetex/__init__.py; do
sed -i -e '/#! *\/usr\/bin\/.*/{1D}' $file
done

cp -a . %{py3dir}

%build
CFLAGS="$RPM_OPT_FLAGS" %{__python} setup.py build

pushd %{py3dir}
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build
popd

%install
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten by setup.py install (and we want the python2 version to be the
# default for now).
pushd %{py3dir}
%{__python3} setup.py install --skip-build  --root=%{buildroot}

# docutils setup.py runs 2to3 on a copy of the tests and puts it in sitelib.
rm -rf %{buildroot}%{python3_sitelib}/test

# Flash file is used for testing docutils but shouldn't be in the installed package.
mv docs/user/rst/images/biohazard.swf ./biohazard.swf 
popd
rm -rf %{buildroot}%{_bindir}/*

%{__python} setup.py install --skip-build --root %{buildroot}

for file in %{buildroot}%_bindir/*.py; do
  mv $file %{buildroot}%_bindir/`basename $file .py`
done

# We want the licenses but don't need this build file
rm -f licenses/docutils.conf

# Flash file is used for testing docutils but shouldn't be in the installed package.
mv docs/user/rst/images/biohazard.swf ./biohazard.swf 

# Make emacs mode available:
emacs -batch -f batch-byte-compile tools/editors/emacs/rst.el
%__install -d -m 755 %{buildroot}%{_datadir}/emacs/site-lisp
%__install -D -m 644 tools/editors/emacs/rst.el* %{buildroot}%{_datadir}/emacs/site-lisp
%__rm -rf tools/editors/emacs

cat > ./rst.el << EOF
(autoload 'rst-mode "rst" "reStructuredText mode" t)
(add-to-list 'auto-mode-alist '("\\.rst$" . rst-mode))
EOF
emacs -batch -f batch-byte-compile rst.el
%__install -d -m 755 %{buildroot}%{_sysconfdir}/emacs/site-start.d
%__install -m 644 rst.el* %{buildroot}%{_sysconfdir}/emacs/site-start.d/


%check
mv  biohazard.swf docs/user/rst/images/biohazard.swf
python test/alltests.py
rm docs/user/rst/images/biohazard.swf

pushd %{py3dir}
mv  biohazard.swf docs/user/rst/images/biohazard.swf
python3 test3/alltests.py
rm docs/user/rst/images/biohazard.swf
popd

%files
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt   
%doc THANKS.txt licenses docs tools/editors 
%{_bindir}/*
%{python_sitelib}/*
%_datadir/emacs/site-lisp/*
%_sysconfdir/emacs/site-start.d/*

%files -n python3-%{srcname}
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt 
%doc THANKS.txt licenses docs tools/editors
%{python3_sitelib}/*



%changelog
* Tue Oct 22 2013 umeabot <umeabot> 0.11-3.mga4
+ Revision: 543374
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.11-2.mga4
+ Revision: 498435
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 0.11-1.mga4
+ Revision: 471627
- Update to 0.11

* Sun Jan 13 2013 umeabot <umeabot> 0.10-0.svn7502.2.mga3
+ Revision: 378760
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 philippem <philippem> 0.10-0.svn7502.1.mga3
+ Revision: 339979
- Update to new upstream

* Tue Sep 04 2012 philippem <philippem> 0.9.1-1.mga3
+ Revision: 288134
- New upstream release 0.9.1

* Sat Oct 22 2011 philippem <philippem> 0.8.1-1.mga2
+ Revision: 157386
- new version 0.8.1

* Mon Jan 31 2011 dmorgan <dmorgan> 0.7-4.mga1
+ Revision: 45389
- Rebuild because of missing provides

* Mon Jan 17 2011 misc <misc> 0.7-3.mga1
+ Revision: 21017
- rebuilt for new python

* Thu Jan 13 2011 ahmad <ahmad> 0.7-2.mga1
+ Revision: 8311
- imported package python-docutils


* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 0.7-2mdv2011.0
+ Revision: 590062
- rebuild for python 2.7

* Sat Aug 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.7-1mdv2011.0
+ Revision: 567230
- update to 0.7

* Mon Jan 04 2010 Lev Givon <lev@mandriva.org> 0.6-1mdv2010.1
+ Revision: 486092
- Update to 0.6.

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 0.5-2mdv2009.1
+ Revision: 319373
- rebuild for new python

* Thu Aug 07 2008 Lev Givon <lev@mandriva.org> 0.5-1mdv2009.0
+ Revision: 265323
- Update to 0.5.
  Make emacs mode automatically available.

* Wed Jul 23 2008 Thierry Vignaud <tv@mandriva.org> 0.4-6mdv2009.0
+ Revision: 242390
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun May 27 2007 Bogdano Arendartchuk <bogdano@mandriva.com> 0.4-4mdv2008.0
+ Revision: 31678
- added requires to python, as it uses pprint

* Fri May 25 2007 Bogdano Arendartchuk <bogdano@mandriva.com> 0.4-3mdv2008.0
+ Revision: 31138
- removed .py suffix of files installed in %%_bindir, as it's done
  by other distros
- force the installation of roman.py


* Wed Dec 13 2006 Nicolas Lécureuil <neoclust@mandriva.org> 0.4-2mdv2007.0
+ Revision: 96084
- Fix File section
- Rebuild for new python
- Import python-docutils

* Fri Mar 03 2006 Austin Acton <austin@mandriva.org> 0.4-1mdk
- New release 0.4

* Thu Jan 12 2006 Michael Scherer <misc@mandriva.org> 0.3.9-2mdk
- Use new python macro
- use mkrel

* Wed Nov 23 2005 Austin Acton <austin@mandriva.org> 0.3.9-1mdk
- 0.3.9

* Mon Mar 14 2005 Michael Scherer <misc@mandrake.org> 0.3.7-1mdk
- New release 0.3.7
- noarch

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 0.3-2mdk
- Rebuild for new python

